@@ -2,10 +2,11 @@
 #'
 #' Merges two \code{rspec} or \code{data.frame} objects into a single \code{rspec} object.
 #'
-#' @param x,y (required) two data frames (or \code{rspec} objects) to merge.
-#' @param by wavelength column name (defaults to \code{"wl"}).
+#' @param x,y (required) \code{rspec} objects to merge.
 #' @param ... additional class arguments.
 #' @return an object of class \code{rspec} for use with \code{pavo} functions.
+#' Will use \code{by = "wl"} if unspecified, or automatically append \code{wl} to the 
+#' \code{by} argument if one is specified.
 #'
 #' @export
 #'
@@ -26,13 +27,20 @@
 #' @author Chad Eliason \email{cme16@@zips.uakron.edu}
 #' @seealso \code{\link{as.rspec}}, \code{\link{aggspec}}
 
-merge.rspec <- function(x, y, by = 'wl', ...) {
+merge.rspec <- function(x, y, ...) {
   
-  if (!(is.rspec(x)&&is.rspec(y))) {stop("One or more invalid rspec objects")}
-  if (!(any(names(x)=='wl')&any(names(y)=='wl'))) {
+  if (!all(is.rspec(x), is.rspec(y))) 
+    stop("One or more invalid rspec objects")
+
+  if (!all('wl' %in% names(x), 'wl' %in% names(y))) 
     stop("Cannot find valid 'wl' column in one or both input objects")
-  }
-  res <- merge.data.frame(x, y, ...)
+  
+  arg <- list(...)  
+  arg$by <- c('wl', arg$by)
+  arg$x <- x
+  arg$y <- y
+  
+  res <- do.call(merge.data.frame, arg)
   class(res) <- c("rspec", "data.frame")
   res
 
