@@ -86,19 +86,19 @@ tcsplot<- function(tcsdata, size = 0.02, alpha = 1, col = 'black',
     
     # can't figure out how to change the character type
     
-    ttv = ttvertex
+    ttv <- ttvertex
     
-    cu = t(col2rgb('#984EA3')) / 255
-    cs = t(col2rgb('#377EB8')) / 255
-    cm = t(col2rgb('#4DAF4A')) / 255
-    cl = t(col2rgb('#E41A1C')) / 255
+    cu <- '#984EA3'
+    cs <- '#377EB8'
+    cm <- '#4DAF4A'
+    cl <- '#E41A1C'
     
     rgl::plot3d(unlist(ttv[c('xu','xs','xm','xl')]),
     		unlist(ttv[c('yu','ys','ym','yl')]),
-    		unlist(ttv[c('zu','zs','zm','zl')]), type = 's', lit = F,
-    		radius = vertexsize, box = F, axes = F, xlab = '', ylab = '', zlab = '',
-    		col = c(rgb(cu[1], cu[2], cu[3]), rgb(cs[1], cs[2], cs[3]), 
-    		rgb(cm[1], cm[2], cm[3]), rgb(cl[1], cl[2], cl[3])))
+    		unlist(ttv[c('zu','zs','zm','zl')]), type = 's', lit = FALSE,
+    		radius = vertexsize, box = FALSE, axes = FALSE, 
+    		xlab = '', ylab = '', zlab = '',
+    		col = c(cu, cs, cm, cl))
     
     rgl::segments3d(ttv[c('xu','xs')], ttv[c('yu','ys')], ttv[c('zu','zs')], 
       color = lcol, lwd = lwd)
@@ -114,10 +114,10 @@ tcsplot<- function(tcsdata, size = 0.02, alpha = 1, col = 'black',
       color = lcol, lwd = lwd)
     
     if(achro == TRUE)
-      rgl::spheres3d(0, 0, 0, col = achrocol, radius = achrosize, lit = F)
+      rgl::spheres3d(0, 0, 0, col = achrocol, radius = achrosize, lit = FALSE)
     
     rgl::spheres3d(tcsdata[,c('x', 'y', 'z')], 
-      radius = size, color = col, alpha = alpha, lit = F)
+      radius = size, color = col, alpha = alpha, lit = FALSE)
     
     if(floor){
       vertices <- c( 
@@ -128,7 +128,7 @@ tcsplot<- function(tcsdata, size = 0.02, alpha = 1, col = 'black',
       				)
       indices <- c(1, 2, 3, 4)
       
-     rgl::wire3d(rgl::qmesh3d(vertices, indices), lit = F)
+     rgl::wire3d(rgl::qmesh3d(vertices, indices), lit = FALSE)
     	}
     	
     if(hspin)
