@@ -22,5 +22,5 @@ tcspoints<- function(tcsdata, size = 0.02, col = 'black', alpha = 1){
     requireNamespace("rgl")
   
   rgl::spheres3d(tcsdata[, c('x', 'y', 'z')], 
-    radius = size, color = col, lit = F, alpha = alpha)
+    radius = size, color = col, lit = FALSE, alpha = alpha)
 }
