@@ -30,7 +30,7 @@ vol <- function(tcsdata, alpha = 0.2, grid = TRUE, fill = TRUE,
     stop('argument "axis" is deprecated, please use "box" instead. see ?plot.colspace or ?tetraplot for more information.', call.=FALSE)
 
 
-  if(attr(tcsdata, 'clrsp') != 'tcs') stop("object is not in tetrahedral color space")
+  if(!is.null(attr(tcsdata, 'clrsp')) && attr(tcsdata, 'clrsp') != 'tcs') stop("object is not in tetrahedral color space")
   
   vol <- t(convhulln(tcsdata[, c('x', 'y', 'z')], options = 'FA')$hull)
   coords <- tcsdata[, c('x', 'y', 'z')]
@@ -85,7 +85,7 @@ vol <- function(tcsdata, alpha = 0.2, grid = TRUE, fill = TRUE,
   
     par(mar= margin)
     
-    P <- do.call(persp, argempty)
+    P <- do.call(perspbox, argempty)
     
     # Save plot info 
     assign("last_plot.tetra", P, envir = .PlotTetraEnv)
